@@ -1,9 +1,9 @@
 # A plugin generator
 
-from .mini_plugin_generator import generate_mini_plugin
+from .mini_plugin_generator import generate_mini_analysis_plugin
 
 plugin_generators = {
-    'mini_plugin': generate_mini_plugin
+    'mini_analysis': generate_mini_analysis_plugin
 }
 
 
@@ -11,7 +11,7 @@ def generate_plugin(plugin_type, **params):
     """ Generates a directory with jana plugin.
 
     Known plugin types:
-        mini_plugin
+        mini_analysis
 
     Usual parameters:
         plugin_name - snake_case defined name (directory name will correspond to it)
